==> maxdb-7.5.00_7.5.00.12.orig.tar.gz: com/sap/dbtech/util/GarbageCursor.java <==
/*


    ========== licence begin GPL
    Copyright (C) 2002-2003 SAP AG

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
    ========== licence end


*/
package com.sap.dbtech.util;

import com.sap.dbtech.jdbc.packet.RequestPacket;
import java.util.Hashtable;
/**
 * Title:        SAP DB JDBC Driver 3.0
 * Description:  Implementation of a JDBC Driver for SAP DB witch fulfill the JDBC 3.0 Standard
 * Copyright:    Copyright (c) 2001
 * Company:      SAP AG
 * @author
 * @version 1.0
 */

public class GarbageCursor extends GarbageCan {
   private Hashtable garbage;

    public GarbageCursor() {
        super(1);
        this.garbage = new Hashtable();
    }

    public void throwIntoGarbageCan (Object obj) {
        this.garbage.put(obj,obj);
    }

    protected int getGarbageSize(){
      return this.garbage.size();
    }

    public synchronized boolean emptyCan(com.sap.dbtech.jdbc.packet.RequestPacket requestPacket)
    {
        if(currentEmptyRun2)
            return false;
        currentEmptyRun2=true;

        boolean packetActionFailed=false;
        java.util.Enumeration cn = this.garbage.keys();
        while(cn.hasMoreElements() &&
              !packetActionFailed) {
            Object o=this.garbage.remove(cn.nextElement());
            packetActionFailed = ! packetAction(requestPacket, o);
            if(packetActionFailed) {
                this.garbage.put(o,o);
            }
        }
        currentEmptyRun2=false;
        return !packetActionFailed;
    }

    public void emptyCan () {
      this.garbage.clear();
    }

    public boolean packetAction(RequestPacket requestPacket, Object obj)
    {
        return requestPacket.initDbsCommand("CLOSE \"" + ((String)obj) + "\"", false, false);
    }

    public boolean restoreFromGarbageCan (Object obj){
      boolean erg = (this.garbage.remove(obj) != null)?true:false;
      return erg;
    }
}

==> maxdb-7.5.00_7.5.00.24.orig.tar.gz: com/sap/dbtech/util/GarbageCursor.java <==
/*


    ========== licence begin GPL
    Copyright (C) 2002-2003 SAP AG

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
    ========== licence end


*/
package com.sap.dbtech.util;

import com.sap.dbtech.jdbc.packet.RequestPacket;
import java.util.Hashtable;
/**
 * Title:        SAP DB JDBC Driver 3.0
 * Description:  Implementation of a JDBC Driver for SAP DB witch fulfill the JDBC 3.0 Standard
 * Copyright:    Copyright (c) 2001
 * Company:      SAP AG
 * @author
 * @version 1.0
 */

public class GarbageCursor extends GarbageCan {
   private Hashtable garbage;

    public GarbageCursor() {
        super(1);
        this.garbage = new Hashtable();
    }

    public void throwIntoGarbageCan (Object obj) {
        this.garbage.put(obj,obj);
    }

    protected int getGarbageSize(){
      return this.garbage.size();
    }

    public synchronized boolean emptyCan(com.sap.dbtech.jdbc.packet.RequestPacket requestPacket)
    {
        if(currentEmptyRun2)
            return false;
        currentEmptyRun2=true;

        boolean packetActionFailed=false;
        java.util.Enumeration cn = this.garbage.keys();
        while(cn.hasMoreElements() &&
              !packetActionFailed) {
            Object o=this.garbage.remove(cn.nextElement());
            packetActionFailed = ! packetAction(requestPacket, o);
            if(packetActionFailed) {
                this.garbage.put(o,o);
            }
        }
        currentEmptyRun2=false;
        return !packetActionFailed;
    }

    public void emptyCan () {
      this.garbage.clear();
    }

    public boolean packetAction(RequestPacket requestPacket, Object obj)
    {
        return requestPacket.initDbsCommand("CLOSE \"" + ((String)obj) + "\"", false, false, java.sql.ResultSet.TYPE_FORWARD_ONLY);
    }

    public boolean restoreFromGarbageCan (Object obj){
      boolean erg = (this.garbage.remove(obj) != null)?true:false;
      return erg;
    }
}
